@@ -28,7 +28,6 @@
 #include <stdlib.h>
 #include <time.h>
 
-#include <dbus/dbus.h>
 #include <glib.h>
 #include <gdbus.h>
 
@@ -36,8 +35,6 @@
 
 #include "driver.h"
 #include "common.h"
-#include "dbus-gsm.h"
-#include "modem.h"
 #include "cssn.h"
 #include "ussd.h"
 
@@ -45,9 +42,9 @@
 
 #define CALL_BARRING_FLAG_CACHED 0x1
 
-static gboolean cb_ss_query_next_lock(gpointer user);
-static gboolean get_query_next_lock(gpointer user);
-static gboolean set_query_next_lock(gpointer user);
+static void cb_ss_query_next_lock(struct ofono_modem *modem);
+static void get_query_next_lock(struct ofono_modem *modem);
+static void set_query_next_lock(struct ofono_modem *modem);
 
 struct call_barring_data {
 	struct ofono_call_barring_ops *ops;
@@ -95,7 +92,7 @@ static inline void emit_barring_changed(struct ofono_modem *modem, int start,
 					int end, const char *type, int cls)
 {
 	struct call_barring_data *cb = modem->call_barring;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	char property_name[64];
 	const char *value;
 	int i;
@@ -120,7 +117,7 @@ static inline void emit_barring_changed(struct ofono_modem *modem, int start,
 	snprintf(property_name, sizeof(property_name), "%s%s",
 			bearer_class_to_string(cls), type);
 
-	dbus_gsm_signal_property_changed(conn, modem->path,
+	ofono_dbus_signal_property_changed(conn, modem->path,
 						CALL_BARRING_INTERFACE,
 						property_name, DBUS_TYPE_STRING,
 						&value);
@@ -167,7 +164,7 @@ static void cb_ss_property_append(struct call_barring_data *cb,
 				bearer_class_to_string(i),
 				cb_locks[lock].name);
 
-		dbus_gsm_dict_append(dict, property_name, DBUS_TYPE_STRING,
+		ofono_dbus_dict_append(dict, property_name, DBUS_TYPE_STRING,
 					&strvalue);
 	}
 }
@@ -257,7 +254,8 @@ static void generate_ss_query_reply(struct ofono_modem *modem)
 	dbus_message_iter_append_basic(&vstruct, DBUS_TYPE_STRING, &ss_fac);
 
 	dbus_message_iter_open_container(&vstruct, DBUS_TYPE_ARRAY,
-					PROPERTIES_ARRAY_SIGNATURE, &dict);
+					OFONO_PROPERTIES_ARRAY_SIGNATURE,
+					&dict);
 
 	/* We report all affected locks only for the special case ones */
 	if (cb->ss_req_lock <= CB_ALL_END) {
@@ -277,7 +275,7 @@ static void generate_ss_query_reply(struct ofono_modem *modem)
 
 	dbus_message_iter_close_container(&iter, &variant);
 
-	dbus_gsm_pending_reply(&cb->pending, reply);
+	__ofono_dbus_pending_reply(&cb->pending, reply);
 }
 
 static void cb_ss_query_next_lock_callback(const struct ofono_error *error,
@@ -293,8 +291,8 @@ static void cb_ss_query_next_lock_callback(const struct ofono_error *error,
 
 		cb->flags &= ~CALL_BARRING_FLAG_CACHED;
 
-		dbus_gsm_pending_reply(&cb->pending,
-					dbus_gsm_failed(cb->pending));
+		__ofono_dbus_pending_reply(&cb->pending,
+					__ofono_error_failed(cb->pending));
 		return;
 	}
 
@@ -302,7 +300,7 @@ static void cb_ss_query_next_lock_callback(const struct ofono_error *error,
 
 	if (cb->query_next < cb->query_end) {
 		cb->query_next += 1;
-		g_timeout_add(0, cb_ss_query_next_lock, modem);
+		cb_ss_query_next_lock(modem);
 		return;
 	}
 
@@ -310,9 +308,8 @@ static void cb_ss_query_next_lock_callback(const struct ofono_error *error,
 	update_barrings(modem, BEARER_CLASS_VOICE);
 }
 
-static gboolean cb_ss_query_next_lock(gpointer user)
+static void cb_ss_query_next_lock(struct ofono_modem *modem)
 {
-	struct ofono_modem *modem = user;
 	struct call_barring_data *cb = modem->call_barring;
 	int cls;
 
@@ -320,8 +317,6 @@ static gboolean cb_ss_query_next_lock(gpointer user)
 
 	cb->ops->query(modem, cb_locks[cb->query_next].fac, cls,
 			cb_ss_query_next_lock_callback, modem);
-
-	return FALSE;
 }
 
 static void cb_ss_set_lock_callback(const struct ofono_error *error,
@@ -332,8 +327,8 @@ static void cb_ss_set_lock_callback(const struct ofono_error *error,
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
 		ofono_debug("Enabling/disabling Call Barring via SS failed");
-		dbus_gsm_pending_reply(&cb->pending,
-					dbus_gsm_failed(cb->pending));
+		__ofono_dbus_pending_reply(&cb->pending,
+					__ofono_error_failed(cb->pending));
 		return;
 	}
 
@@ -370,7 +365,7 @@ static gboolean cb_ss_control(struct ofono_modem *modem,
 				DBusMessage *msg)
 {
 	struct call_barring_data *cb = modem->call_barring;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	int cls = BEARER_CLASS_DEFAULT;
 	const char *fac;
 	DBusMessage *reply;
@@ -378,7 +373,7 @@ static gboolean cb_ss_control(struct ofono_modem *modem,
 	int i;
 
 	if (cb->pending) {
-		reply = dbus_gsm_busy(msg);
+		reply = __ofono_error_busy(msg);
 		g_dbus_send_message(conn, reply);
 
 		return TRUE;
@@ -423,7 +418,7 @@ static gboolean cb_ss_control(struct ofono_modem *modem,
 	}
 
 	if (!operation) {
-		reply = dbus_gsm_not_implemented(msg);
+		reply = __ofono_error_not_implemented(msg);
 		g_dbus_send_message(conn, reply);
 
 		return TRUE;
@@ -478,7 +473,7 @@ static gboolean cb_ss_control(struct ofono_modem *modem,
 	return TRUE;
 
 bad_format:
-	reply = dbus_gsm_invalid_format(msg);
+	reply = __ofono_error_invalid_format(msg);
 	g_dbus_send_message(conn, reply);
 	return TRUE;
 }
@@ -492,11 +487,11 @@ static void cb_set_passwd_callback(const struct ofono_error *error, void *data)
 	if (error->type == OFONO_ERROR_TYPE_NO_ERROR)
 		reply = dbus_message_new_method_return(cb->pending);
 	else {
-		reply = dbus_gsm_failed(cb->pending);
+		reply = __ofono_error_failed(cb->pending);
 		ofono_debug("Changing Call Barring password via SS failed");
 	}
 
-	dbus_gsm_pending_reply(&cb->pending, reply);
+	__ofono_dbus_pending_reply(&cb->pending, reply);
 }
 
 static gboolean cb_ss_passwd(struct ofono_modem *modem, const char *sc,
@@ -504,12 +499,12 @@ static gboolean cb_ss_passwd(struct ofono_modem *modem, const char *sc,
 				DBusMessage *msg)
 {
 	struct call_barring_data *cb = modem->call_barring;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *reply;
 	const char *fac;
 
 	if (cb->pending) {
-		reply = dbus_gsm_busy(msg);
+		reply = __ofono_error_busy(msg);
 		g_dbus_send_message(conn, reply);
 
 		return TRUE;
@@ -536,7 +531,7 @@ static gboolean cb_ss_passwd(struct ofono_modem *modem, const char *sc,
 
 	return TRUE;
 bad_format:
-	reply = dbus_gsm_invalid_format(msg);
+	reply = __ofono_error_invalid_format(msg);
 	g_dbus_send_message(conn, reply);
 	return TRUE;
 }
@@ -626,7 +621,7 @@ static inline void cb_append_property(struct call_barring_data *cb,
 	snprintf(property_name, sizeof(property_name), "%s%s",
 			bearer_class_to_string(cls), property);
 
-	dbus_gsm_dict_append(dict, property_name, DBUS_TYPE_STRING,
+	ofono_dbus_dict_append(dict, property_name, DBUS_TYPE_STRING,
 				&value);
 }
 
@@ -647,7 +642,8 @@ static void cb_get_properties_reply(struct ofono_modem *modem, int mask)
 	dbus_message_iter_init_append(reply, &iter);
 
 	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY,
-			PROPERTIES_ARRAY_SIGNATURE, &dict);
+					OFONO_PROPERTIES_ARRAY_SIGNATURE,
+					&dict);
 
 	for (j = 1; j <= BEARER_CLASS_PAD; j = j << 1) {
 		if ((j & mask) == 0)
@@ -661,7 +657,7 @@ static void cb_get_properties_reply(struct ofono_modem *modem, int mask)
 
 	dbus_message_iter_close_container(&iter, &dict);
 
-	dbus_gsm_pending_reply(&cb->pending, reply);
+	__ofono_dbus_pending_reply(&cb->pending, reply);
 }
 
 static void get_query_lock_callback(const struct ofono_error *error,
@@ -679,7 +675,7 @@ static void get_query_lock_callback(const struct ofono_error *error,
 
 	if (cb->query_next < CB_ALL_END) {
 		cb->query_next = cb->query_next + 1;
-		g_timeout_add(0, get_query_next_lock, modem);
+		get_query_next_lock(modem);
 		return;
 	}
 
@@ -687,15 +683,12 @@ static void get_query_lock_callback(const struct ofono_error *error,
 	update_barrings(modem, BEARER_CLASS_VOICE);
 }
 
-static gboolean get_query_next_lock(gpointer user)
+static void get_query_next_lock(struct ofono_modem *modem)
 {
-	struct ofono_modem *modem = user;
 	struct call_barring_data *cb = modem->call_barring;
 
 	cb->ops->query(modem, cb_locks[cb->query_next].fac,
 			BEARER_CLASS_DEFAULT, get_query_lock_callback, modem);
-
-	return FALSE;
 }
 
 static DBusMessage *cb_get_properties(DBusConnection *conn, DBusMessage *msg,
@@ -705,10 +698,10 @@ static DBusMessage *cb_get_properties(DBusConnection *conn, DBusMessage *msg,
 	struct call_barring_data *cb = modem->call_barring;
 
 	if (cb->pending)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!cb->ops->query)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	cb->pending = dbus_message_ref(msg);
 
@@ -734,8 +727,8 @@ static void set_query_lock_callback(const struct ofono_error *error,
 
 		cb->flags &= ~CALL_BARRING_FLAG_CACHED;
 
-		dbus_gsm_pending_reply(&cb->pending,
-					dbus_gsm_failed(cb->pending));
+		__ofono_dbus_pending_reply(&cb->pending,
+					__ofono_error_failed(cb->pending));
 		return;
 	}
 
@@ -743,24 +736,21 @@ static void set_query_lock_callback(const struct ofono_error *error,
 
 	if (cb->query_next < cb->query_end) {
 		cb->query_next += 1;
-		g_timeout_add(0, set_query_next_lock, modem);
+		set_query_next_lock(modem);
 		return;
 	}
 
-	dbus_gsm_pending_reply(&cb->pending,
+	__ofono_dbus_pending_reply(&cb->pending,
 				dbus_message_new_method_return(cb->pending));
 	update_barrings(modem, BEARER_CLASS_VOICE);
 }
 
-static gboolean set_query_next_lock(gpointer user)
+static void set_query_next_lock(struct ofono_modem *modem)
 {
-	struct ofono_modem *modem = user;
 	struct call_barring_data *cb = modem->call_barring;
 
 	cb->ops->query(modem, cb_locks[cb->query_next].fac,
 			BEARER_CLASS_DEFAULT, set_query_lock_callback, modem);
-
-	return FALSE;
 }
 
 static void set_lock_callback(const struct ofono_error *error, void *data)
@@ -770,8 +760,8 @@ static void set_lock_callback(const struct ofono_error *error, void *data)
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
 		ofono_debug("Enabling/disabling a lock failed");
-		dbus_gsm_pending_reply(&cb->pending,
-					dbus_gsm_failed(cb->pending));
+		__ofono_dbus_pending_reply(&cb->pending,
+					__ofono_error_failed(cb->pending));
 		return;
 	}
 
@@ -865,43 +855,43 @@ static DBusMessage *cb_set_property(DBusConnection *conn, DBusMessage *msg,
 	int mode;
 
 	if (cb->pending)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!dbus_message_iter_init(msg, &iter))
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&iter, &name);
 
 	dbus_message_iter_next(&iter);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_VARIANT)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_recurse(&iter, &var);
 
 	if (dbus_message_iter_get_arg_type(&var) != DBUS_TYPE_STRING)
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&var, &value);
 
 	if (!cb_lock_property_lookup(name, value, BEARER_CLASS_VOICE,
 					&lock, &cls, &mode))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (dbus_message_iter_next(&iter)) {
 		if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-			return dbus_gsm_invalid_args(msg);
+			return __ofono_error_invalid_args(msg);
 
 		dbus_message_iter_get_basic(&iter, &passwd);
 		if (!is_valid_pin(passwd))
-			return dbus_gsm_invalid_format(msg);
+			return __ofono_error_invalid_format(msg);
 	}
 
 	if (!cb->ops->set)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	cb_set_query_bounds(cb, cb_locks[lock].fac, FALSE);
 
@@ -919,8 +909,8 @@ static void disable_all_callback(const struct ofono_error *error, void *data)
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
 		ofono_debug("Disabling all barring failed");
-		dbus_gsm_pending_reply(&cb->pending,
-					dbus_gsm_failed(cb->pending));
+		__ofono_dbus_pending_reply(&cb->pending,
+					__ofono_error_failed(cb->pending));
 		return;
 	}
 
@@ -937,20 +927,20 @@ static DBusMessage *cb_disable_all(DBusConnection *conn, DBusMessage *msg,
 	const char *passwd = "";
 
 	if (cb->pending)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!dbus_message_iter_init(msg, &iter))
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&iter, &passwd);
 	if (!is_valid_pin(passwd))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	if (!cb->ops->set)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	cb_set_query_bounds(cb, fac, FALSE);
 
@@ -988,29 +978,29 @@ static DBusMessage *cb_set_passwd(DBusConnection *conn, DBusMessage *msg,
 	const char *old_passwd, *new_passwd;
 
 	if (cb->pending)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!dbus_message_iter_init(msg, &iter))
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&iter, &old_passwd);
 	if (!is_valid_pin(old_passwd))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	dbus_message_iter_next(&iter);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&iter, &new_passwd);
 	if (!is_valid_pin(new_passwd))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	if (!cb->ops->set_passwd)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	cb->pending = dbus_message_ref(msg);
 	cb->ops->set_passwd(modem, "AB", old_passwd, new_passwd,
@@ -1045,7 +1035,7 @@ static GDBusSignalTable cb_signals[] = {
 static void call_barring_incoming_enabled_notify(int idx, void *userdata)
 {
 	struct ofono_modem *modem = userdata;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *signal;
 
 	signal = dbus_message_new_signal(modem->path,
@@ -1062,7 +1052,7 @@ static void call_barring_incoming_enabled_notify(int idx, void *userdata)
 static void call_barring_outgoing_enabled_notify(int idx, void *userdata)
 {
 	struct ofono_modem *modem = userdata;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *signal;
 
 	signal = dbus_message_new_signal(modem->path,
@@ -1079,7 +1069,7 @@ static void call_barring_outgoing_enabled_notify(int idx, void *userdata)
 int ofono_call_barring_register(struct ofono_modem *modem,
 				struct ofono_call_barring_ops *ops)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 
 	if (!modem || !ops)
 		return -1;
@@ -1102,7 +1092,7 @@ int ofono_call_barring_register(struct ofono_modem *modem,
 		return -1;
 	}
 
-	modem_add_interface(modem, CALL_BARRING_INTERFACE);
+	ofono_modem_add_interface(modem, CALL_BARRING_INTERFACE);
 
 	cb_register_ss_controls(modem);
 
@@ -1116,12 +1106,12 @@ int ofono_call_barring_register(struct ofono_modem *modem,
 
 void ofono_call_barring_unregister(struct ofono_modem *modem)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 
 	if (!modem->call_barring)
 		return;
 
-	modem_remove_interface(modem, CALL_BARRING_INTERFACE);
+	ofono_modem_remove_interface(modem, CALL_BARRING_INTERFACE);
 	g_dbus_unregister_interface(conn, modem->path, CALL_BARRING_INTERFACE);
 
 	cb_unregister_ss_controls(modem);
